@@ -2,8 +2,6 @@ from __future__ import absolute_import
 
 from typing import TYPE_CHECKING, overload
 
-from applitools.core.fluent import CheckTarget
-
 from .selenium_check_settings import SeleniumCheckSettings
 
 if TYPE_CHECKING:
@@ -16,10 +14,12 @@ if TYPE_CHECKING:
         FrameNameOrId,
     )
 
+    from .target_path import Locator
+
 __all__ = ("Target",)
 
 
-class Target(CheckTarget):
+class Target(object):
     """
     Target for an eyes.check_window/region.
     """
@@ -53,6 +53,12 @@ class Target(CheckTarget):
         # type: (BySelector) -> SeleniumCheckSettings
         pass
 
+    @staticmethod  # noqa
+    @overload
+    def region(target_path):
+        # type: (Locator) -> SeleniumCheckSettings
+        pass
+
     @staticmethod  # noqa
     def region(region):
         return SeleniumCheckSettings().region(region)
@@ -81,6 +87,12 @@ class Target(CheckTarget):
         # type: (BySelector) -> SeleniumCheckSettings
         pass
 
+    @staticmethod  # noqa
+    @overload
+    def frame(target_path):
+        # type: (Locator) -> SeleniumCheckSettings
+        pass
+
     @staticmethod  # noqa
     def frame(frame):
         return SeleniumCheckSettings().frame(frame)
